@@ -142,7 +142,7 @@ LOGGING = {
 AUTHENTICATION_BACKENDS = (
     'mongoengine.django.auth.MongoEngineBackend',
 )
-SESSION_ENGINE = 'mongoengine.django.sessions'
+#SESSION_ENGINE = 'mongoengine.django.sessions'
 
 from mongoengine import connect
 connect('example_blog')
